==> qtjambi-network-debuginfo-macos-6.5.3.jar: sources/QtJambiNetwork/QHttp1Configuration_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtnetwork-config.h>
#if QT_CONFIG(http)
#include <QtNetwork/qhttp1configuration.h>
#endif //QT_CONFIG(http)
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiNetwork/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(http)


void deleter_QHttp1Configuration(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHttp1Configuration")
    QHttp1Configuration *_ptr = reinterpret_cast<QHttp1Configuration *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(http)

// emitting (writeConstructors)
// new QHttp1Configuration()
void __qt_construct_QHttp1Configuration_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHttp1Configuration()")
#if QT_CONFIG(http)
    Q_UNUSED(__java_arguments)
    QHttp1Configuration *__qt_this = new(__qtjambi_ptr) QHttp1Configuration();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
}

// new QHttp1Configuration(QHttp1Configuration)
void __qt_construct_QHttp1Configuration_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHttp1Configuration(QHttp1Configuration)")
#if QT_CONFIG(http)
    jobject other0 = __java_arguments[0].l;
    const QHttp1Configuration& __qt_other0 = qtjambi_cast<const QHttp1Configuration& >(__jni_env, other0);
    QHttp1Configuration *__qt_this = new(__qtjambi_ptr) QHttp1Configuration(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
}

// destruct QHttp1Configuration
void __qt_destruct_QHttp1Configuration(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHttp1Configuration")

#if QT_CONFIG(http)

    reinterpret_cast<QHttp1Configuration*>(ptr)->~QHttp1Configuration();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(http)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHttp1Configuration::QHttp1Configuration()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_initialize_1native__Lio_qt_network_QHttp1Configuration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHttp1Configuration::QHttp1Configuration()")
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHttp1Configuration_0, sizeof(QHttp1Configuration), typeid(QHttp1Configuration), false, &deleter_QHttp1Configuration, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHttp1Configuration::QHttp1Configuration(QHttp1Configuration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_initialize_1native__Lio_qt_network_QHttp1Configuration_2Lio_qt_network_QHttp1Configuration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHttp1Configuration::QHttp1Configuration(QHttp1Configuration)")
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHttp1Configuration_1, sizeof(QHttp1Configuration), typeid(QHttp1Configuration), false, &deleter_QHttp1Configuration, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHttp1Configuration::numberOfConnectionsPerHost()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_numberOfConnectionsPerHost_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        const QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttp1Configuration::numberOfConnectionsPerHost()const", __qt_this)
        qsizetype __qt_return_value = __qt_this->numberOfConnectionsPerHost();
        __java_return_value = jlong(__qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHttp1Configuration::operator=(QHttp1Configuration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_assign_1native_1cref_1QHttp1Configuration__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttp1Configuration::operator=(QHttp1Configuration)", __qt_this)
        const QHttp1Configuration& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QHttp1Configuration>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHttp1Configuration::operator==(QHttp1Configuration,QHttp1Configuration)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_operator_1equal_1native_1cref_1QHttp1Configuration__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttp1Configuration::operator==(QHttp1Configuration,QHttp1Configuration)", __qt_this)
        const QHttp1Configuration& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QHttp1Configuration>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(rhs1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHttp1Configuration::setNumberOfConnectionsPerHost(qsizetype)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_setNumberOfConnectionsPerHost_1native_1qsizetype__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong amount0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttp1Configuration::setNumberOfConnectionsPerHost(qsizetype)", __qt_this)
        __qt_this->setNumberOfConnectionsPerHost(static_cast<qsizetype>(amount0));
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(amount0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHttp1Configuration::swap(QHttp1Configuration&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_swap_1native_1ref_1QHttp1Configuration__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttp1Configuration::swap(QHttp1Configuration&)", __qt_this)
        QHttp1Configuration& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QHttp1Configuration>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {

#if QT_CONFIG(http)

        QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(http)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(http)

        const QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(http)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QHttp1Configuration(){
    using namespace RegistryAPI;

#if QT_CONFIG(http)

    const std::type_info& typeId = registerValueTypeInfo<QHttp1Configuration>("QHttp1Configuration", "io/qt/network/QHttp1Configuration");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHttp1Configuration, {
        ConstructorInfo(&__qt_construct_QHttp1Configuration_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QHttp1Configuration_1, "Lio/qt/network/QHttp1Configuration;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHttp1Configuration);
    registerMetaType<QHttp1Configuration>("QHttp1Configuration");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(http)

}

==> qtjambi-network-debuginfo-macos-6.5.4.jar: sources/QtJambiNetwork/QHttp1Configuration_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtnetwork-config.h>
#if QT_CONFIG(http)
#include <QtNetwork/qhttp1configuration.h>
#endif //QT_CONFIG(http)
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiNetwork/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(http)


void deleter_QHttp1Configuration(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHttp1Configuration")
    QHttp1Configuration *_ptr = reinterpret_cast<QHttp1Configuration *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(http)

// emitting (writeConstructors)
// new QHttp1Configuration()
void __qt_construct_QHttp1Configuration_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHttp1Configuration()")
#if QT_CONFIG(http)
    Q_UNUSED(__java_arguments)
    QHttp1Configuration *__qt_this = new(__qtjambi_ptr) QHttp1Configuration();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
}

// new QHttp1Configuration(QHttp1Configuration)
void __qt_construct_QHttp1Configuration_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHttp1Configuration(QHttp1Configuration)")
#if QT_CONFIG(http)
    jobject other0 = __java_arguments[0].l;
    const QHttp1Configuration& __qt_other0 = qtjambi_cast<const QHttp1Configuration& >(__jni_env, other0);
    QHttp1Configuration *__qt_this = new(__qtjambi_ptr) QHttp1Configuration(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
}

// destruct QHttp1Configuration
void __qt_destruct_QHttp1Configuration(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHttp1Configuration")

#if QT_CONFIG(http)

    reinterpret_cast<QHttp1Configuration*>(ptr)->~QHttp1Configuration();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(http)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHttp1Configuration::QHttp1Configuration()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_initialize_1native__Lio_qt_network_QHttp1Configuration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHttp1Configuration::QHttp1Configuration()")
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHttp1Configuration_0, sizeof(QHttp1Configuration), typeid(QHttp1Configuration), false, &deleter_QHttp1Configuration, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHttp1Configuration::QHttp1Configuration(QHttp1Configuration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_initialize_1native__Lio_qt_network_QHttp1Configuration_2Lio_qt_network_QHttp1Configuration_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHttp1Configuration::QHttp1Configuration(QHttp1Configuration)")
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHttp1Configuration_1, sizeof(QHttp1Configuration), typeid(QHttp1Configuration), false, &deleter_QHttp1Configuration, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHttp1Configuration::numberOfConnectionsPerHost()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_numberOfConnectionsPerHost_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        const QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttp1Configuration::numberOfConnectionsPerHost()const", __qt_this)
        qsizetype __qt_return_value = __qt_this->numberOfConnectionsPerHost();
        __java_return_value = jlong(__qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHttp1Configuration::operator!=(QHttp1Configuration,QHttp1Configuration)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_operator_1not_1equal_1native_1cref_1QHttp1Configuration__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttp1Configuration::operator!=(QHttp1Configuration,QHttp1Configuration)", __qt_this)
        const QHttp1Configuration& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QHttp1Configuration>(rhs1);
        __java_return_value = (*__qt_this) != __qt_rhs1;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(rhs1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHttp1Configuration::operator=(QHttp1Configuration)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_assign_1native_1cref_1QHttp1Configuration__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttp1Configuration::operator=(QHttp1Configuration)", __qt_this)
        const QHttp1Configuration& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QHttp1Configuration>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHttp1Configuration::setNumberOfConnectionsPerHost(qsizetype)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_setNumberOfConnectionsPerHost_1native_1qsizetype__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong amount0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttp1Configuration::setNumberOfConnectionsPerHost(qsizetype)", __qt_this)
        __qt_this->setNumberOfConnectionsPerHost(static_cast<qsizetype>(amount0));
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(amount0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHttp1Configuration::swap(QHttp1Configuration&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_swap_1native_1ref_1QHttp1Configuration__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(http)
        QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttp1Configuration::swap(QHttp1Configuration&)", __qt_this)
        QHttp1Configuration& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QHttp1Configuration>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(http)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {

#if QT_CONFIG(http)

        QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(http)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QHttp1Configuration_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(http)

        const QHttp1Configuration *__qt_this = QtJambiAPI::objectFromNativeId<QHttp1Configuration>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(http)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QHttp1Configuration(){
    using namespace RegistryAPI;

#if QT_CONFIG(http)

    const std::type_info& typeId = registerValueTypeInfo<QHttp1Configuration>("QHttp1Configuration", "io/qt/network/QHttp1Configuration");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHttp1Configuration, {
        ConstructorInfo(&__qt_construct_QHttp1Configuration_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QHttp1Configuration_1, "Lio/qt/network/QHttp1Configuration;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHttp1Configuration);
    registerMetaType<QHttp1Configuration>("QHttp1Configuration");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(http)

}
